// -*- c++ -*-
// Generated by gtkmmproc -- DO NOT MODIFY!
#ifndef _GDLMM_DOCKITEM_P_H
#define _GDLMM_DOCKITEM_P_H


#include <gdlmm/private/dockobject_p.h>

#include <glibmm/class.h>

namespace Gdl
{

class DockItem_Class : public Glib::Class
{
public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  typedef DockItem CppObjectType;
  typedef GdlDockItem BaseObjectType;
  typedef GdlDockItemClass BaseClassType;
  typedef DockObject_Class CppClassParent;
  typedef GdlDockObjectClass BaseClassParent;

  friend class DockItem;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

  const Glib::Class& init();


  static void class_init_function(void* g_class, void* class_data);

  static Glib::ObjectBase* wrap_new(GObject*);

protected:

  //Callbacks (default signal handlers):
  //These will call the *_impl member methods, which will then call the existing default signal callbacks, if any.
  //You could prevent the original default signal handlers being called by overriding the *_impl method.
  static void dock_drag_begin_callback(GdlDockItem* self);
  static void dock_drag_end_callback(GdlDockItem* self, gboolean p0);
  static void dock_drag_motion_callback(GdlDockItem* self, GdkDevice* p0, gint p1, gint p2);

  //Callbacks (virtual functions):
};


} // namespace Gdl


#endif /* _GDLMM_DOCKITEM_P_H */

